@@ -1,4 +1,5 @@
 import argparse
+import platform
 
 from . import __version__ as version
 from .ffmpeg_progress_yield import FfmpegProgress
@@ -18,6 +19,12 @@ def main() -> None:
     parser.add_argument(
         "-n", "--dry-run", action="store_true", help="Print ffmpeg command and exit."
     )
+    parser.add_argument(
+        "-p",
+        "--progress-only",
+        action="store_true",
+        help="Print progress only and do not print stderr at exit.",
+    )
     parser.add_argument(
         "ffmpeg_command",
         type=str,
@@ -40,7 +47,10 @@ def main() -> None:
         for progress in ff.run_command_with_progress():
             print(f"{progress}/100")
 
-    print(ff.stderr)
+    if platform.system() == "Windows":
+        print("\x1b[K", end="")
+    if not args.progress_only:
+        print(ff.stderr)
 
 
 if __name__ == "__main__":
